|Build Status|

Pulumi Docker Helpers
=====================

Pulumi helper library for interacting with Docker. Used so that this
logic can be shared with other parts of the Pulumi stack.

.. |Build Status| image:: https://travis-ci.com/pulumi/pulumi-docker.svg?token=eHg7Zp5zdDDJfTjY8ejq&branch=master
   :target: https://travis-ci.com/pulumi/pulumi-docker
